import { defineConfig } from 'vite'
import { fileURLToPath, URL } from 'node:url'
import vue from '@vitejs/plugin-vue'
import AutoImport from 'unplugin-auto-import/vite'
// import resolve from 'rollup-plugin-node-resolve'
import commonjs from '@rollup/plugin-commonjs'
import babel from 'rollup-plugin-babel'
// import path from 'path'
// // 处理css定义的变量
// const pathResolve = (p: string) => {
//   return path.resolve(__dirname, p)
// }
export default defineConfig({
  plugins: [
    vue(),
    AutoImport({
      eslintrc: {
        enabled: false, // true用于生成eslint配置,生成后改回false，避免重复生成消耗
        filepath: './.eslintrc-auto-import.json',
        globalsPropValue: true
      },
      imports: ['vue', 'vue-router'],
      dts: 'src/types/auto-import.d.ts',
      // 是否在vue模板中自动导入
      vueTemplate: true
    })
  ],
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url))
    }
  },
  css: {
    preprocessorOptions: {
      less: {
        javascriptEnabled: true,
        modifyVars: {
          // 在这里自定义主题色等样式
          'primary-color': '#1677ff'
        }
      }
    }
  },
  build: {
    //打包文件目录
    // outDir: 'mis-component',
    //是否压缩
    minify: true,
    // minify: 'terser',
    rollupOptions: {
      input: 'src/index.ts',
      treeshake: true,
      external: [
        /^vue(\/.+|$)/,
        /^ant-design-vue(\/.+|$)/,
        /^@ant-design\/icons-vue/,
        'lodash',
        'mitt'
      ],
      preserveEntrySignatures: 'strict',
      output: [
        {
          //打包格式
          format: 'es',
          //打包后文件名
          entryFileNames: '[name].ts',
          //让打包目录和我们目录对应
          preserveModules: true,
          exports: 'named',
          dir: 'mis-component'
          // externalLiveBindings: false
          // inlineDynamicImports: true
        }
      ],
      plugins: [
        babel({
          extensions: ['.vue'], // 无后缀名引用时，需要识别 .vue 文件
          exclude: '**/node_modules/**' // 排除node_modules
        }),
        commonjs()
      ]
    },
    lib: {
      entry: 'src/index.ts'
      // name: 'sss-ui-plus',
      // fileName: 'sss-ui-plus',
      // formats: ['es']
    }
  }
})
